@@ -1,4 +1,5 @@
-from ..utils import data_type_converter, create_dataframe
+import altair as alt
+from .utils import data_type_converter, create_dataframe
 
 def relplot(data=None, *, x=None, y=None,color=None,interactive=None,kind="scatter",width=200,height=200):
 
